/*	NUMBERS.H
	1992		Keith L. Robertson
	This file is placed in the public domain by the author.

	Contains shorter definitions of numeric types and max and min values.
	Also contains binary and trinary max() and min() functions (macros).
*/
#ifndef NUMBERS_H
#define NUMBERS_H


typedef unsigned char	uchar;
typedef   signed char	schar;
#define		MIN_SCHAR	(0x80)
#define		MAX_SCHAR	(0x7f)
#define		MAX_UCHAR	(0xff)
#if	_CHAR_UNSIGNED
    #define	MIN_CHAR	(0x00)
    #define	MAX_CHAR	(0xff)
#else
    #define	MIN_CHAR	(0x80)
    #define	MAX_CHAR	(0x7f)
#endif


typedef unsigned short	ushort;
#define		MIN_SHORT	(0x8000)
#define		MAX_SHORT	(0x7fff)
#define		MAX_USHORT	(0xffff)


typedef unsigned long	ulong;
#define		MIN_LONG	((long) 0x80000000)
#define		MAX_LONG	((long) 0x7fffffff)
#define		MAX_ULONG	((ulong)0xffffffff)


typedef unsigned int	uint;
#if	sizeof(int) != 4
    #define	MIN_INT		((int) 0x8000)
    #define	MAX_INT		((int) 0x7fff)
    #define	MAX_UINT	((uint)0xffff)
#else
    #define	MIN_INT		((int) 0x80000000)
    #define	MAX_INT		((int) 0x7fffffff)
    #define	MAX_UINT	((uint)0xffffffff)
#endif


/*	Divide, rounding up	*/
#define		divUP(dividend,divisor)	((dividend+(divisor-1))/divisor)


/*	For efficiency, do not use expressions as max or min arguments */
#define		max(a,b)	((a)>(b) ? (a) : (b))
#define		min(a,b)	((a)<(b) ? (a) : (b))
#define		max3(a,b,c)	((a)>(b) ? max(a,c) : max(b,c))
#define		min3(a,b,c)	((a)<(b) ? min(a,c) : min(b,c))

#endif  NUMBERS_H
